import * as echarts from 'echarts'
export const chartOptions = {
  setSBJCOption(data) {
    const option = {
      legend: {
        data: ['Allocated Budget', 'Actual Spending'],
        textStyle: {
          color: '#fff',
          fontSize: 14
        }
      },

      radar: {
        shape: 'circle', // 外环的形状（圆形/多边形）
        splitNumber: 5, // 外环圈数
        indicator: [
          // 每项指标的最大值设置
          // { name: 'Sales', max: 6500 },
          // { name: 'Administration', max: 16000 },
          // { name: 'Information Technology', max: 30000 },
          // { name: 'Customer Support', max: 38000 },
          // { name: 'Development', max: 52000 },
          // { name: 'Marketing', max: 25000 }
          { name: 'Sales' },
          { name: 'Administration' },
          { name: 'Information Technology' },
          { name: 'Customer Support' },
          { name: 'Development' },
          { name: 'Marketing' }
        ],
        splitLine: {
          // 外环分割线样式
          lineStyle: {
            color: '#45BCE4',
            type: 'dashed'
          }
        },
        splitArea: {
          show: false
        },
        axisLine: {
          // 坐标轴线样式设置
          lineStyle: {
            color: '#45BCE4'
          }
        }
      },
      series: [
        {
          name: 'Budget vs spending',
          type: 'radar',
          data: [
            {
              value: [4200, 3000, 20000, 35000, 50000, 18000],
              name: 'Allocated Budget',
              itemStyle: {
                // 多边形线颜色
                color: '#47EB99'
              },
              areaStyle: {
                opacity: 0.5
              }
            },
            {
              value: [5000, 14000, 28000, 26000, 42000, 21000],
              name: 'Actual Spending',
              itemStyle: {
                color: '#47EAEB'
              },
              areaStyle: {
                opacity: 0.5
              }
            }
          ]
        }
      ]
    }
    return option
  },

  setSBJC2Option(data) {
    function Pie() {
      let dataArr = []
      for (var i = 0; i < 150; i++) {
        if (i % 2 === 0) {
          dataArr.push({
            name: (i + 1).toString(),
            value: 50,
            itemStyle: {
              normal: {
                color: '#00AFFF',
                borderWidth: 0,
                borderColor: 'rgba(0,0,0,0)'
              }
            }
          })
        } else {
          dataArr.push({
            name: (i + 1).toString(),
            value: 100,
            itemStyle: {
              normal: {
                color: 'rgba(0,0,0,0)',
                borderWidth: 0,
                borderColor: 'rgba(0,0,0,0)'
              }
            }
          })
        }
      }
      return dataArr
    }
    const option = {
      // title: {
      //   text: '',
      //   textStyle: {
      //     fontWeight: 'normal',
      //     fontSize: 25,
      //     color: 'rgb(97, 142, 205)'
      //   }
      // },
      series: [
        {
          // value: 50, //  内容 配合formatter
          type: 'liquidFill',
          radius: '70%', // 控制中间圆球的尺寸（此处可以理解为距离外圈圆的距离控制）
          center: ['50%', '50%'],
          data: [
            0.6,
            {
              value: 0.6,
              direction: 'left' //波浪方向
            }
          ], // data个数代表波浪数
          backgroundStyle: {
            borderWidth: 1,
            color: 'rgba(62, 208, 255, 1)' // 球体本景色
          },
          amplitude: '6%', //波浪的振幅
          // 修改波浪颜色
          // color: ['#0286ea', 'l#0b99ff'], // 每个波浪不同颜色，颜色数组长度为对应的波浪个数
          color: [
            {
              type: 'linear',
              x: 0,
              y: 0,
              x2: 0,
              y2: 1,
              colorStops: [
                {
                  offset: 1,
                  color: '#6CDEFC'
                },
                {
                  offset: 0,
                  color: '#429BF7'
                }
              ],
              globalCoord: false
            }
          ],
          label: {
            // formatter: 0.87 * 100 + '\n%',
            formatter: 0.6 * 100 + '\n{d|%}',
            //  formatter: function(params){
            //     return params.value* 100 + " \n%";
            // },
            rich: {
              d: {
                fontSize: 36
              }
            },
            textStyle: {
              fontSize: 48,
              color: '#fff'
            }
          },
          outline: {
            show: false
          }
        },
        {
          type: 'pie',
          z: 1,
          center: ['50%', '50%'],
          radius: ['72%', '73.5%'], // 控制外圈圆的粗细
          hoverAnimation: false,
          data: [
            {
              name: '',
              value: 500,
              labelLine: {
                show: false
              },
              itemStyle: {
                color: '#00AFFF'
              },
              emphasis: {
                labelLine: {
                  show: false
                },
                itemStyle: {
                  color: '#00AFFF'
                }
              }
            }
          ]
        },
        {
          //外发光
          type: 'pie',
          z: 1,
          zlevel: -1,
          radius: ['70%', '90.5%'],
          center: ['50%', '50%'],
          hoverAnimation: false,
          clockWise: false,
          itemStyle: {
            normal: {
              borderWidth: 20,
              color: 'rgba(224,242,255,0.3)'
            }
          },
          label: {
            show: false
          },
          data: [100]
        },
        {
          //底层外发光
          type: 'pie',
          z: 1,
          zlevel: -2,
          radius: ['70%', '100%'],
          center: ['50%', '50%'],
          hoverAnimation: false,
          clockWise: false,
          itemStyle: {
            normal: {
              borderWidth: 20,
              color: 'rgba(224,242,255,.2)'
            }
          },
          label: {
            show: false
          },
          data: [100]
        },
        {
          type: 'pie',
          zlevel: 0,
          silent: true,
          radius: ['78%', '80%'],
          z: 1,
          label: {
            show: false
          },
          labelLine: {
            show: false
          },
          data: Pie()
        }
      ]
    }
    return option
  },

  setChart1(data = 0) {
    const option = {
      title: {
        text: data,
        textStyle: {
          fontSize: 20,
          color: 'rgba(255, 255, 255, 0.7)',
          rich: {
            a: {
              fontSize: 18
            }
          }
        },
        x: 'center',
        y: '40%'
      },
      graphic: [
        {
          type: 'group',
          left: '45%',
          top: '50%',
          children: [
            {
              type: 'text',
              z: 100,
              left: '10',
              top: 'middle'
              // style: {
              //   fill: '#ffffff',
              //   text: data,
              //   font: '36px'
              // }
            }
          ]
        }
      ],
      series: [
        {
          name: '水球图',
          type: 'liquidFill',
          radius: '90%',
          // center: ["50%", "55%"],
          // waveAnimation: 5, // 动画时长
          // amplitude: 10, // 振幅
          data: [data / 100],
          color: [
            {
              type: 'linear',
              x: 0,
              y: 1,
              x2: 0,
              y2: 0,
              colorStops: [
                {
                  offset: 1,
                  color: ['rgba(2,144,255,0.4)'] // 0% 处的颜色
                },
                {
                  offset: 0,
                  color: ['rgba(45,175,230,0.8)'] // 100% 处的颜色
                }
              ],
              global: false // 缺省为 false
            }
          ],
          label: {
            formatter: ''
          },
          outline: {
            show: true,
            borderDistance: 0,
            itemStyle: {
              borderColor: new echarts.graphic.LinearGradient(0, 1, 0, 0, [
                {
                  offset: 1,
                  color: 'rgba(21, 80, 161, 0.01)'
                },
                {
                  offset: 0,
                  color: 'rgba(15, 115, 238, 0.6)'
                }
              ]),
              borderWidth: 3
            }
          },
          backgroundStyle: {
            color: new echarts.graphic.RadialGradient(0.5, 0.5, 0.5, [
              {
                offset: 1,
                color: 'rgba(15, 115, 238,0.3)'
              },
              {
                offset: 0.95,
                color: 'rgba(15, 115, 238, 0.5)'
              },
              {
                offset: 0.8,
                color: 'rgba(15, 115, 238, 0.3)'
              },
              {
                offset: 0.4,
                color: 'rgba(21, 80, 161, 0.01)'
              }
            ])
          }
        }
      ]
    }
    return option
  },
  setChart2() {
    let color = ['#0E7CE2', '#FF8352', '#E271DE', '#F8456B', '#00FFFF', '#4AEAB0']
    let echartData = [
      {
        name: '安全帽佩戴报警',
        value: '13'
      },
      {
        name: '非法闯入报警',
        value: '33'
      },
      {
        name: 'C类',
        value: '13'
      },
      {
        name: 'D类',
        value: '13'
      }
    ]

    let formatNumber = function (num) {
      let reg = /(?=(\B)(\d{3})+$)/g
      return num.toString().replace(reg, ',')
    }

    const option = {
      color: color,
      // tooltip: {
      //     trigger: 'item'
      // },
      legend: {
        orient: 'vertical',
        icon: 'rect',
        x: '5%',
        y: 'center',
        itemWidth: 12,
        itemHeight: 12,
        align: 'left',
        textStyle: {
          rich: {
            name: {
              fontSize: 12,
              color: 'rgba(255, 255, 255, 0.7)'
            },
            value: {
              fontSize: 16,
              padding: [0, 5, 0, 5],
              color: 'rgba(255, 255, 255, 0.7)'
            },
            unit: {
              fontSize: 12
            }
          }
        },
        formatter: function (name) {
          let res = echartData.filter((v) => v.name === name)
          res = res[0] || {}
          let unit = res.unit || ''
          // return '{name|' + name + '}  {value|' + res.value + '}{unit|' + unit + '}'
          return '{name|' + name + '} '
        },
        data: echartData
      },
      series: [
        {
          type: 'pie',
          radius: ['20%', '40%'],
          center: ['65%', '60%'],
          color,
          data: echartData.map((item, index) => {
            return {
              label: {
                color: color[index]
              },
              ...item
            }
          }),
          hoverAnimation: false,
          itemStyle: {
            borderWidth: 2
          },
          labelLine: {
            show: true,
            length: 30,
            length2: 60,
            lineStyle: {
              color: '#0080ff'
            }
          },
          label: {
            show: true,
            formatter: (params) => {
              return '{icon|●}{name|' + params.name + '}{value|' + formatNumber(params.value) + '}'
            },
            padding: [0, -80, 25, -100],
            rich: {
              icon: {
                fontSize: 16
              },
              name: {
                fontSize: 12,
                padding: [0, 10, 0, 4]
              },
              value: {
                fontSize: 12,
                fontWeight: 'bold'
              }
            }
          }
        }
      ]
    }
    return option
  }
}
