/**
 * @Description: 用于全屏
 * @Author zcf
 * @Date 2023-09-12 14:25
 * @E-mail boyzcf@qq.com
 */
import screenfull from 'screenfull'

document.fullscreenEnabled =
  document.fullscreenEnabled ||
  document.mozFullScreenEnabled ||
  document.documentElement.webkitRequestFullScreen

let parentNode = null
let divDom = null

/**
 *
 * @param {目标元素} targetElement
 * @param {触发元素} triggerElement
 */
export default function useScreenfull(targetElement, triggerElement) {
  const isFullscreen = ref(false)
  const screenfullChangeHandler = () => {
    isFullscreen.value = screenfull.isFullscreen
  }
  const openAllScreen = (dom) => {
    if (targetElement === '.screen-full-target') {
      if (screenfull.isEnabled) {
        screenfull.toggle(dom)
        screenfull.on('change', screenfullChangeHandler)
      }
    } else {
      if (isFullscreen.value) {
        parentNode.appendChild(dom)
        document.querySelector('.screen-full-target').removeChild(divDom)
        isFullscreen.value = false
      } else {
        parentNode = dom.parentNode
        divDom = document.createElement('div')
        divDom.style.position = 'fixed'
        divDom.style.top = '0'
        divDom.style.left = '0'
        divDom.style.right = '0'
        divDom.style.bottom = '0'
        divDom.style.zIndex = '9999'
        divDom.style.background = '#000000'
        divDom.style.display = 'flex'
        divDom.style.justifyContent = 'center'
        divDom.style.alignItems = 'center'


        divDom.appendChild(dom)
        document.querySelector('.screen-full-target').appendChild(divDom)
        isFullscreen.value = true
      }
    }
  }

  onMounted(() => {
    nextTick(() => {
      const triggerDoms = document.querySelectorAll(triggerElement)
      const targetDoms = document.querySelectorAll(targetElement)
      for (let i = 0; i < triggerDoms.length; i++) {
        triggerDoms[i].addEventListener('click', () => openAllScreen(targetDoms[i]), false)
        triggerDoms[i].addEventListener('touchstart', () => openAllScreen(targetDoms[i]), false)
      }
    })
  })
  onUnmounted(() => {
    screenfull.off('change', screenfullChangeHandler)
  })
  return { isFullscreen }
}
