/**
 * @Description: 放大缩小实现
 * @Author zcf
 * @Date 2023-09-13 13:18
 * @E-mail boyzcf@qq.com
 */
import { useOutsideSystemStore } from '@/stores/modules/system.js'
// const { API_VIEW_PREVIEW_POST } = useRequest()
const useSystem = useOutsideSystemStore()
export default function useWheel(containerEl, partUrl, className = '.ps-video') {
  let container = containerEl,
    scaleEle = document.querySelector(className + partUrl.UUID),
    x = 0,
    y = 0,
    scale = 1,
    scaleEleW = 806,
    scaleEleH = 453,
    minScale = 1,
    maxScale = 20,
    isDown = false, // 按下标识
    lastPointermove = { x: 0, y: 0 }, // 用于计算鼠标移动距离
    offsetX = 0,
    offsetY = 0

  // 滚轮缩放、放大逻辑
  const wheelHandle = (e) => {
    let ratio = 1.1
    // 缩小
    if (e.deltaY > 0) {
      ratio = 1 / 1.1
    }
    // 限制缩放倍数
    const onscale = scale * ratio
    if (onscale > maxScale) {
      ratio = maxScale / scale
      scale = maxScale
    } else if (onscale < minScale) {
      ratio = minScale / scale
      scale = minScale
    } else {
      scale = onscale
    }
    // 计算偏移量
    const origin = {
      x: (ratio - 1) * scaleEleW * 0.5,
      y: (ratio - 1) * scaleEleH * 0.5
    }
    x -= (ratio - 1) * (e.offsetX - x - (container.clientWidth - scaleEleW) * 0.5) - origin.x
    y -= (ratio - 1) * (e.offsetY - y - (container.clientHeight - scaleEleH) * 0.5) - origin.y
    offsetX = Math.min(
      Math.max(x, container.clientWidth - (container.clientWidth * (scale + 1)) / 2),
      (container.clientWidth * (scale - 1)) / 2
    )
    offsetY = Math.min(
      Math.max(y, container.clientHeight - (container.clientHeight * (scale + 1)) / 2),
      (container.clientHeight * (scale - 1)) / 2
    )
    x = offsetX
    y = offsetY
    scaleEle.style.transform = `matrix(${scale}, 0, 0, ${scale}, ${offsetX}, ${offsetY})`
    // useSystem.temp[partUrl.UUID] = {
    //   x,
    //   y,
    //   scale,
    //   isDown,
    //   lastPointermove,
    //   offsetX,
    //   offsetY
    // }
  }
  const mousemoveHandle = (e) => {
    let transformStyle = scaleEle.style.transform

    // 解析矩阵的缩放值
    let matrixValues = transformStyle.split('(')[1].split(')')[0].split(',')
    let mscaleX = parseFloat(matrixValues[0])
    let mscaleY = parseFloat(matrixValues[3])

    // 计算实际宽度
    scaleEleW = scaleEle.offsetWidth * mscaleX
    scaleEleH = scaleEle.offsetHeight * mscaleY
    if (isDown) {
      if (scale == 1) return
      let moveX = e.offsetX - lastPointermove.x
      let moveY = e.offsetY - lastPointermove.y
      offsetX += moveX
      offsetY += moveY
      // 边界限制
      if (offsetX > 0) {
        if (offsetX >= (container.clientWidth * (scale - 1)) / 2) {
          offsetX = x
        }
      } else if (offsetX < 0) {
        if (offsetX <= container.clientWidth - (container.clientWidth * (scale + 1)) / 2) {
          offsetX = x
        }
      }
      if (offsetY > 0) {
        if (offsetY >= (container.clientHeight * (scale - 1)) / 2) {
          offsetY = y
        }
      } else if (offsetY < 0) {
        if (offsetY <= container.clientHeight - (container.clientHeight * (scale + 1)) / 2) {
          offsetY = y
        }
      }
      x = offsetX
      y = offsetY
      scaleEle.style.transform = `matrix(${scale}, 0, 0, ${scale}, ${offsetX}, ${offsetY})`
    }
  }

  const params = {
    ...partUrl
  }
  const baseH = useSystem.videoArrange.HeightMain
  const baseW = useSystem.videoArrange.WidthMain
  const boxH = container.offsetHeight / 2
  const boxW = container.offsetWidth / 2
  // 全景更新细节初始化x y
  watch(
    () => useSystem.partObj,
    (newV) => {
      params.PartCenterX = newV.PartCenterX
      params.PartCenterY = newV.PartCenterY
    },
    { deep: true }
  )
  const mouseupHandle = (e) => {
    isDown = false
    const moveX = e.offsetX - lastPointermove.x
    const moveY = e.offsetY - lastPointermove.y
    // // 水平往左拖
    // if (e.offsetX < lastPointermove.x) {
    //   // 是否超出最大边界
    //   if (parseInt(params.PartCenterX) >= baseW - boxW) {
    //     params.PartCenterX = baseW - boxW + ''
    //   } else {
    //     params.PartCenterX = `${parseInt(params.PartCenterX) + Math.abs(moveX)}`
    //   }
    //   //水平往右拖
    // } else if (e.offsetX > lastPointermove.x) {
    //   // 是否超出最小边界
    //   if (parseInt(params.PartCenterX) <= boxW) {
    //     params.PartCenterX = boxW
    //   } else {
    //     params.PartCenterX = `${parseInt(params.PartCenterX) - Math.abs(moveX)}`
    //   }
    // }

    // // 垂直往上拖
    // if (e.offsetY < lastPointermove.y) {
    //   if (parseInt(params.PartCenterY) >= baseH - boxH) {
    //     params.PartCenterY = baseH - boxH + ''
    //   } else {
    //     params.PartCenterY = `${parseInt(params.PartCenterY) + Math.abs(moveY)}`
    //   }
    //   //垂直往下拖
    // } else if (e.offsetY > lastPointermove.y) {
    //   if (parseInt(params.PartCenterY) <= boxH) {
    //     params.PartCenterY = boxH + ''
    //   } else {
    //     params.PartCenterY = `${parseInt(params.PartCenterY) - Math.abs(moveY)}`
    //   }
    // }
    // // 防止重复修改细节
    // if (moveX == 0 && moveY == 0) {
    //   return
    // }

    // API_VIEW_PREVIEW_POST({ type: 1, x: +params.PartCenterX, y: +params.PartCenterY })
  }
  const mousedownHandle = (e) => {
    console.log(123);
    e.preventDefault()
    isDown = true
    lastPointermove = { x: e.offsetX, y: e.offsetY }
  }
  // 全屏重置细节缩放
  watch(
    () => useSystem.isFull,
    () => {
      x = 0
      y = 0
      scale = 1
      scaleEleW = 806
      scaleEleH = 453
      minScale = 1
      maxScale = 20
      isDown = false // 按下标识
      lastPointermove = { x: 0, y: 0 } // 用于计算鼠标移动距离
      offsetX = 0
      offsetY = 0
      scaleEle.style.transform = `matrix(1, 0, 0, 1, 0, 0)`
    }
  )

  scaleEle.style.transform = `matrix(${scale}, 0, 0, ${scale}, ${offsetX}, ${offsetY})`
  // 拖拽查看
  // 绑定鼠标点击
  container.addEventListener('mousedown', mousedownHandle, false)
  // 绑定鼠标抬起
  container.addEventListener('mouseup', mouseupHandle, false)
  // 绑定鼠标移动
  container.addEventListener('mousemove', mousemoveHandle)


  container.addEventListener('touchstart', mousedownHandle, false)
  // 绑定鼠标抬起
  container.addEventListener('touchend', mouseupHandle, false)
  // 绑定鼠标移动
  container.addEventListener('touchmove', mousemoveHandle)

  scaleEle.addEventListener('wheel', wheelHandle, { passive: true })
}
